/*
 * TOFU Circuit Simulator
 * Copyright (C) 2007 Michael Birken
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 * 
 * http://www.meatfighter.com/tofu
 */

package tofu;

import java.util.*;

public abstract class Component {
  
  private final static Map<Class,String[]> parameterMap 
      = new HashMap<Class,String[]>();  
  private Stack<Node> propagateStack;
  private Map<String,Node> nodeMap = new HashMap<String,Node>();  
  private String initParam;
  
  protected static void setParameters(Class c, String... parameters) {
    parameterMap.put(c, parameters);
  } 
  
  public static String[] getParameters(Class c) {
    return parameterMap.get(c);
  }
  
  protected String[] getParameters() {
    return getParameters(getClass());
  }
  
  public void setInitParam(String initParam) {
    this.initParam = initParam;
  }
  
  public String getInitParam() {
    return initParam;
  }
  
  protected void setPropagationStack(Stack<Node> propagateStack) {
    this.propagateStack = propagateStack;  
  }
  
  protected void putNode(String name, Node node) {
    nodeMap.put(name, node);
  }
  
  protected Node getNode(String name) {
    return nodeMap.get(name);
  }
  
  protected void energizeNode(Node node) {
    if (node.getVoltage() == Voltage.Z) {
      node.setVoltage(Voltage.H);
      if (node.getComponents().size() > 1) {
        propagateStack.push(node);
      }
    }
  }
  
  public abstract void init();
  public abstract void flow();
  public abstract void update();  
}
