/*
 * TOFU Circuit Simulator
 * Copyright (C) 2007 Michael Birken
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
 * 
 * http://www.meatfighter.com/tofu
 */

package tofu;

public class Relay extends Component {

  static {
    setParameters(Relay.class, "coil", "lever", "open", "closed");
  }
  
  private Node coilNode;
  private Node leverNode;
  private Node closedNode;
  private Node openNode;
  private boolean active;
  
  public void init() {
    coilNode = getNode("coil");
    leverNode = getNode("lever");
    closedNode = getNode("closed");
    openNode = getNode("open");
  }

  public void flow() {
    Node contactNode = active ? openNode : closedNode;
    if (contactNode.getVoltage() == Voltage.H
        && leverNode.getVoltage() == Voltage.Z) {
      energizeNode(leverNode);
    } else if (leverNode.getVoltage() == Voltage.H
        && contactNode.getVoltage() == Voltage.Z) {
      energizeNode(contactNode);
    }
  }
  
  public void update() {
    active = coilNode.getVoltage() == Voltage.H;
  } 
}
